summaryrefslogtreecommitdiffstats
path: root/kicker/taskmanager/taskmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/taskmanager/taskmanager.h')
-rw-r--r--kicker/taskmanager/taskmanager.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kicker/taskmanager/taskmanager.h b/kicker/taskmanager/taskmanager.h
index dd730e410..8f5876360 100644
--- a/kicker/taskmanager/taskmanager.h
+++ b/kicker/taskmanager/taskmanager.h
@@ -262,12 +262,12 @@ public:
bool showInPager() const { return _info.state() ^ NET::SkipPager; }
/**
* Returns the tqgeometry for this window
*/
- TQRect tqgeometry() const { return _info.tqgeometry(); }
+ TQRect geometry() const { return _info.geometry(); }
/**
* Returns the tqgeometry for the from of this window
*/
TQRect frameGeometry() const { return _info.frameGeometry(); }
@@ -427,7 +427,7 @@ signals:
/**
* Indicates that this task has changed in some way.
*/
- void changed(bool tqgeometryChangeOnly);
+ void changed(bool geometryChangeOnly);
/**
* Indicates that the icon for this task has changed.
@@ -529,7 +529,7 @@ public:
/**
* The name of the starting task (if known).
*/
- TQString text() const { return _data.tqfindName(); }
+ TQString text() const { return _data.findName(); }
/**
* The name of the executable of the starting task.
@@ -539,7 +539,7 @@ public:
/**
* The name of the icon to be used for the starting task.
*/
- TQString icon() const { return _data.tqfindIcon(); }
+ TQString icon() const { return _data.findIcon(); }
void update( const KStartupInfoData& data );
const KStartupInfoId& id() const { return _id; }
@@ -616,7 +616,7 @@ public:
bool isOnTop(const Task*);
/**
* Tells the task manager whether or not we care about tqgeometry
* updates. This generates a lot of activity so should only be used
* when necessary.
*/
@@ -262,12 +262,12 @@ public:
bool showInPager() const { return _info.state() ^ NET::SkipPager; }
/**
- * Returns the tqgeometry for this window
+ * Returns the geometry for this window
*/
@@ -262,12 +262,12 @@ public:
/**
- * Returns the tqgeometry for the from of this window
+ * Returns the geometry for the from of this window
*/
TQRect frameGeometry() const { return _info.frameGeometry(); }
@@ -616,7 +616,7 @@ public:
bool isOnTop(const Task*);
/**
- * Tells the task manager whether or not we care about tqgeometry
+ * Tells the task manager whether or not we care about geometry
* updates. This generates a lot of activity so should only be used
* when necessary.